@@ -231,9 +231,6 @@ class AppWithDataSets(App):
 
         data_set.init_parameters_with_defaults()  # Must be done here and not in AppDataSet.__init__ as requires data set to have ID.
 
-        for execute_function_widget in [w for w in self.get_all_widgets() if w.get_type() == ExecuteFunction.TYPE]:
-            data_set.init_function_execution_info(execute_function_widget)
-
         if example_data_set_name and self.get_examples():
             try:
                 populate_example = self.get_examples().get(example_data_set_name)
