@@ -56,9 +56,12 @@ class ClassWsMapping(ClassTabularDataMapping):
         super(ClassWsMapping, self).__init__(class_, attribute_column_aliases, process_objects, get_objects, objects)
 
     @classmethod
-    def create_ordered_mappings_from_sqla_classes(cls, sqla_classes=None, include_parameters_if_any=True):
+    def create_ordered_mappings_from_sqla_classes(cls, sqla_classes=None, include_parameters_if_any=True, app=None):
         """
-        :param sqla_classes: List of SQLA classes to create mappings for. If None, assumes create for all classes in app.
+        :param sqla_classes: List of SQLA classes to create mappings for. If None, create for all classes in app.
+        :type sqla_classes: list
+        :param app: (Default: App from which this function is called) App in which sqla classes are defined.
+        :type app: :class:`tropofy.app.App`
         :returns: list of :class:`tropofy.database.read_write_xl.ClassWsMapping`
         :rtype: list
         """
@@ -66,7 +69,7 @@ class ClassWsMapping(ClassTabularDataMapping):
         if not isinstance(sqla_classes, collections.Iterable):
             raise TypeError("param sqla_classes must be an iterable (e.g. list)")
 
-        app = threadlocal.get_current_request().app
+        app = app if app is not None else threadlocal.get_current_request().app
         class_ws_mappings = []
         if app:
             tables_mapped_to_classes = app.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app()
@@ -384,6 +387,9 @@ class ExcelReader(object):
 
                 transaction.abort()
                 raise TropofyFileImportExportException(progress_messages)
+        print("\nLoading data from Excel...")
+        for msg in progress_messages:
+            print(msg)
         return progress_messages
 
     @classmethod
