@@ -50,7 +50,9 @@ class Chart(Widget):
                 'get_chart_options': self.get_chart_options(data_set),
                 'get_table_data': self.get_table_data(data_set),
                 'get_table_schema': self.get_table_schema(data_set),
-                'get_chart_type': self.get_chart_type(data_set)
+                'get_chart_type': self.get_chart_type(data_set),
+                'get_chart_title': self.get_chart_title(data_set),
+                'get_chart_height': self.get_chart_height(data_set),
             }
 
     def get_chart_options(self, data_set):
@@ -169,6 +171,28 @@ class Chart(Widget):
         """
         raise NotImplementedError
 
+    def get_chart_title(self, data_set):
+        """Specify a title for the chart.
+
+        .. note:: This title is independent of any title set in :func:`tropofy.widgets.Chart.get_chart_options`.
+         It is recommended that this method only be used for charts where no title can be set through :func:`tropofy.widgets.Chart.get_chart_options`. For example, a TIMELINE chart.
+         Furthermore, the height of this title is not includes in the chart height specified in :func:`tropofy.widgets.Chart.get_chart_height`.
+
+        :returns: Title for a chart
+        :rtype: str
+        """
+        return None
+
+    def get_chart_height(self, data_set):
+        """Specify the height in px of the charts.
+
+        Defaults to 600.
+
+        :returns: Height of the chart in px
+        :rtype: int
+        """
+        return 600
+
 
 class FilteredChart(Chart):
     """A FilteredChart is a :class:`tropofy.widgets.Chart`, linked to a :class:`tropofy.widgets.Filter`.
