@@ -27,7 +27,7 @@ from simplekml import Kml, Style, IconStyle, Icon, LineStyle
 from tropofy.app import AppWithDataSets, Step, StepGroup
 from tropofy.widgets import ExecuteFunction, SimpleGrid, KMLMap, Chart
 from tropofy.database.tropofy_orm import DataSetMixin
-from tropofy.database import read_write_xl
+from tropofy.file_io import read_write_xl
 
 
 class Commodity(DataSetMixin):
@@ -422,7 +422,7 @@ class NetworkFlowOptimisationApp(AppWithDataSets):
 
     @staticmethod
     def load_network_flow_example_data(data_set):
-        read_write_xl.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('network_flow_example_data.xlsx'))
+        read_write_xl.ExcelReader.load_data_from_excel_file_on_disk(data_set, data_set.app.get_path_of_file_in_app_folder('network_flow_example_data.xlsx'))
         
 def inflow_matches_node_and_commodity(flow, node, commodity):
     return flow.dest_name == node.name and flow.commod_name == commodity.name
